==> spip_4.0.4.orig.tar.xz: plugins-dist/porte_plume/lang/barreoutils_br.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/barreoutils?lang_cible=br
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'barre_a_accent_grave' => 'Enlakaat un À',
	'barre_adresse' => 'chomlec’h',
	'barre_aide' => 'Grit gant beradennoù lizherennerezhel evit kempenn ar framm',
	'barre_alignerdroite' => '[/Steudañ a-zehou/] ar rannbennad',
	'barre_ancres' => 'Eorioù',
	'barre_barre' => 'Barrennañ an destenn',
	'barre_bulle' => 'Stlennglogorenn',
	'barre_c_cedille_maj' => 'Enlakaat ur Ç',
	'barre_cadre' => 'Placer dans une &lt;cadre&gt;zone de saisie de texte&lt;/cadre&gt;',
	'barre_caracteres' => 'Arouezioù ispisial',
	'barre_centrer' => '[|Kreizhañ|] ar rannbennad',
	'barre_chercher' => 'Klask Amsaviñ',
	'barre_clean' => 'Naetañ ar c’hod eus holl balizennoù HTML',
	'barre_code' => 'Lakaat e-stumm ur &lt;code&gt;c’hod stlenneg&lt;/code&gt;',
	'barre_desindenter' => 'Digreskiñ ur rollenn',
	'barre_e_accent_aigu' => 'Enlakaat un É',
	'barre_e_accent_grave' => 'Enlakaat un È',
	'barre_ea' => 'Enlakaat un æ',
	'barre_ea_maj' => 'Enlakaat un Æ',
	'barre_encadrer' => '[(Sternañ)] ar rannbennad',
	'barre_eo' => 'Enlakaat un œ',
	'barre_eo_maj' => 'Enlakaat un Œ',
	'barre_euro' => 'Enlakaat ar simbol €',
	'barre_exposant' => 'Lakaat an destenn e &lt;sup&gt;marc’her&lt;/sup&gt;',
	'barre_formatages_speciaux' => 'Furmad arbennig',
	'barre_galerie' => 'Digor ar skeudennaoueg',
	'barre_gestion_anc_bulle' => 'Klogor skoazell war-zu un eor',
	'barre_gestion_anc_caption' => 'Eorioù',
	'barre_gestion_anc_cible' => 'Pal an eor',
	'barre_gestion_anc_inserer' => 'Kemmañ en un eor',
	'barre_gestion_anc_nom' => 'Anv an eor',
	'barre_gestion_anc_pointer' => 'Poentañ war-zu un eor',
	'barre_gestion_caption' => 'Alc’houez ha Diverrañ',
	'barre_gestion_colonne' => 'Niver a vannoù',
	'barre_gestion_cr_casse' => 'Doujañ da vent al lizherennoù',
	'barre_gestion_cr_changercasse' => 'Chañch ment al lizherennoù',
	'barre_gestion_cr_changercassemajuscules' => 'Lakaat e pennlizherenn',
	'barre_gestion_cr_changercasseminuscules' => 'Lakaat e lizherenn vunut',
	'barre_gestion_cr_chercher' => 'Klask',
	'barre_gestion_cr_entier' => 'Ger a-bezh',
	'barre_gestion_cr_remplacer' => 'Amsaviñ',
	'barre_gestion_cr_tout' => 'Kemmañ pep tra',
	'barre_gestion_entete' => 'Talbenn',
	'barre_gestion_ligne' => 'Niver a linennoù',
	'barre_gestion_taille' => 'Braster stabil',
	'barre_glossaire' => 'Mont-e barzh ar [?geriaoueg] (Wikipedia)',
	'barre_gras' => 'Lakaat e {{ giz-druz}}',
	'barre_guillemets' => 'Gronnañ gant « klochedigoù »',
	'barre_guillemets_simples' => 'Gronnañ gant “klochedigoù eil live”',
	'barre_indenter' => 'Kreskaat ur rollenn',
	'barre_inserer_cadre' => 'Lakaat ur c’hod furmadet en araok (stern)',
	'barre_inserer_caracteres' => 'Enlakaat arouezioù ispisial',
	'barre_inserer_code' => 'Lakaat kod kompoder e-barzh (kod)',
	'barre_intertitre' => 'Kemmañ e  {{{iztitl}}}',
	'barre_italic' => 'Lakaat e {lizherenn stouet}',
	'barre_langue' => 'Yezh berraet',
	'barre_lien' => 'Kemmañ [liamm gourskrid->http://...]',
	'barre_lien_externe' => 'Liamm diavaez',
	'barre_lien_input' => 'Mar plij, lakait pal ho treistkevre (ret eo deoc’h reiñ un URL Internet dindan ar stumm 
http://www.mysite.com pe giz-all niverenn ur pennad-skrid war al lec’hienn-mañ)',
	'barre_liste_ol' => 'Lakaat e rollenn niverennet',
	'barre_liste_ul' => 'Lakaat e rollenn',
	'barre_lorem_ipsum' => 'Enlakaat ur rannbennad faos',
	'barre_lorem_ipsum_3' => 'Enlakaat teir rannbennad faos',
	'barre_miseenevidence' => 'Lakaat an destenn [*anat*]',
	'barre_note' => 'Kemmañ en [[Notenn traoñ pajenn]]',
	'barre_paragraphe' => 'Krouiñ ur rannbennad',
	'barre_petitescapitales' => 'Lakaat an destenn e &lt;sc&gt;pennlizherennoù bihan&lt;/sc&gt;',
	'barre_poesie' => 'Mettre en forme comme une &lt;poesie&gt;poésie&lt;/poesie&gt;',
	'barre_preview' => 'Mod rakwelet',
	'barre_quote' => '<quote>menegiñ ur gemenadenn/quote>',
	'barre_stats' => 'Dikouez statistikoù an destenn',
	'barre_tableau' => 'Lakaat/kemmañ (diuzañ anezhañ a-raok) un daolenn',

	// C
	'config_info_enregistree' => 'Ardremmez savetaet',

	// E
	'editer' => 'Embann',
	'explication_barre_outils_public' => ' CSS ha Javascript ar varennoù benveg
	(astenn  doug pluenn) zo karget war al lec’hienn foran
	
	a zegas barennoù benveg er foromoù, kreionoù foran pe pluginoù-all
pa vez aotreet gant ar ardremmez.',
	'explication_barre_outils_public_2' => 'Bez e c’halloc’h non pas kargañ ar scriptoù-mañ evit sklerijenniñ pajennoù foran. 
Neuze, forzh penaos vefe renket ar forom, pe kreionoù ha pluginoù, benveg Quill ebet ne vo war al lec’hienn foran en un doare emgefreek.',

	// I
	'info_barre_outils_public' => 'Barennoù benveg foran',
	'info_porte_plume_titre' => 'Ardremm ar barennoù benveg',

	// L
	'label_barre_outils_public_non' => 'Arabat kargañ skriptoù ar barennoù benveg e-barzh al lec’hienn foran.',
	'label_barre_outils_public_oui' => 'Kargañ skriptoù ar barennoù benveg e-barzh al lec’hienn foran.',

	// V
	'voir' => 'Gwelet en araok'
);

==> spip_4.2.9+dfsg.orig.tar.xz: plugins-dist/porte_plume/lang/barreoutils_br.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/barreoutils?lang_cible=br
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'barre_a_accent_grave' => 'Enlakaat un À',
	'barre_adresse' => 'chomlec’h',
	'barre_aide' => 'Grit gant beradennoù lizherennerezhel evit kempenn ar framm',
	'barre_alignerdroite' => '[/Steudañ a-zehou/] ar rannbennad',
	'barre_ancres' => 'Eorioù',
	'barre_barre' => 'Barrennañ an destenn',
	'barre_bulle' => 'Stlennglogorenn',
	'barre_c_cedille_maj' => 'Enlakaat ur Ç',
	'barre_cadre' => 'Placer dans une &lt;cadre&gt;zone de saisie de texte&lt;/cadre&gt;',
	'barre_caracteres' => 'Arouezioù ispisial',
	'barre_centrer' => '[|Kreizhañ|] ar rannbennad',
	'barre_chercher' => 'Klask Amsaviñ',
	'barre_clean' => 'Naetañ ar c’hod eus holl balizennoù HTML',
	'barre_code' => 'Lakaat e-stumm ur &lt;code&gt;c’hod stlenneg&lt;/code&gt;',
	'barre_desindenter' => 'Digreskiñ ur rollenn',
	'barre_e_accent_aigu' => 'Enlakaat un É',
	'barre_e_accent_grave' => 'Enlakaat un È',
	'barre_ea' => 'Enlakaat un æ',
	'barre_ea_maj' => 'Enlakaat un Æ',
	'barre_encadrer' => '[(Sternañ)] ar rannbennad',
	'barre_eo' => 'Enlakaat un œ',
	'barre_eo_maj' => 'Enlakaat un Œ',
	'barre_euro' => 'Enlakaat ar simbol €',
	'barre_exposant' => 'Lakaat an destenn e &lt;sup&gt;marc’her&lt;/sup&gt;',
	'barre_formatages_speciaux' => 'Furmad arbennig',
	'barre_galerie' => 'Digor ar skeudennaoueg',
	'barre_gestion_anc_bulle' => 'Klogor skoazell war-zu un eor',
	'barre_gestion_anc_caption' => 'Eorioù',
	'barre_gestion_anc_cible' => 'Pal an eor',
	'barre_gestion_anc_inserer' => 'Kemmañ en un eor',
	'barre_gestion_anc_nom' => 'Anv an eor',
	'barre_gestion_anc_pointer' => 'Poentañ war-zu un eor',
	'barre_gestion_caption' => 'Alc’houez ha Diverrañ',
	'barre_gestion_colonne' => 'Niver a vannoù',
	'barre_gestion_cr_casse' => 'Doujañ da vent al lizherennoù',
	'barre_gestion_cr_changercasse' => 'Chañch ment al lizherennoù',
	'barre_gestion_cr_changercassemajuscules' => 'Lakaat e pennlizherenn',
	'barre_gestion_cr_changercasseminuscules' => 'Lakaat e lizherenn vunut',
	'barre_gestion_cr_chercher' => 'Klask',
	'barre_gestion_cr_entier' => 'Ger a-bezh',
	'barre_gestion_cr_remplacer' => 'Amsaviñ',
	'barre_gestion_cr_tout' => 'Kemmañ pep tra',
	'barre_gestion_entete' => 'Talbenn',
	'barre_gestion_ligne' => 'Niver a linennoù',
	'barre_gestion_taille' => 'Braster stabil',
	'barre_glossaire' => 'Mont-e barzh ar [?geriaoueg] (Wikipedia)',
	'barre_gras' => 'Lakaat e {{ giz-druz}}',
	'barre_guillemets' => 'Gronnañ gant « klochedigoù »',
	'barre_guillemets_simples' => 'Gronnañ gant “klochedigoù eil live”',
	'barre_indenter' => 'Kreskaat ur rollenn',
	'barre_inserer_cadre' => 'Lakaat ur c’hod furmadet en araok (stern)', # MODIF
	'barre_inserer_caracteres' => 'Enlakaat arouezioù ispisial',
	'barre_inserer_code' => 'Lakaat kod kompoder e-barzh (kod)', # MODIF
	'barre_intertitre' => 'Kemmañ e  {{{iztitl}}}',
	'barre_italic' => 'Lakaat e {lizherenn stouet}',
	'barre_langue' => 'Yezh berraet',
	'barre_lien' => 'Kemmañ [liamm gourskrid->http://...]',
	'barre_lien_externe' => 'Liamm diavaez',
	'barre_lien_input' => 'Mar plij, lakait pal ho treistkevre (ret eo deoc’h reiñ un URL Internet dindan ar stumm 
http://www.mysite.com pe giz-all niverenn ur pennad-skrid war al lec’hienn-mañ)',
	'barre_liste_ol' => 'Lakaat e rollenn niverennet',
	'barre_liste_ul' => 'Lakaat e rollenn',
	'barre_lorem_ipsum' => 'Enlakaat ur rannbennad faos',
	'barre_lorem_ipsum_3' => 'Enlakaat teir rannbennad faos',
	'barre_miseenevidence' => 'Lakaat an destenn [*anat*]',
	'barre_note' => 'Kemmañ en [[Notenn traoñ pajenn]]',
	'barre_paragraphe' => 'Krouiñ ur rannbennad',
	'barre_petitescapitales' => 'Lakaat an destenn e &lt;sc&gt;pennlizherennoù bihan&lt;/sc&gt;',
	'barre_poesie' => 'Mettre en forme comme une &lt;poesie&gt;poésie&lt;/poesie&gt;',
	'barre_preview' => 'Mod rakwelet',
	'barre_quote' => '<quote>menegiñ ur gemenadenn/quote>',
	'barre_stats' => 'Dikouez statistikoù an destenn',
	'barre_tableau' => 'Lakaat/kemmañ (diuzañ anezhañ a-raok) un daolenn',

	// C
	'config_info_enregistree' => 'Ardremmez savetaet',

	// E
	'editer' => 'Embann',
	'explication_barre_outils_public' => ' CSS ha Javascript ar varennoù benveg
	(astenn  doug pluenn) zo karget war al lec’hienn foran
	
	a zegas barennoù benveg er foromoù, kreionoù foran pe pluginoù-all
pa vez aotreet gant ar ardremmez.',
	'explication_barre_outils_public_2' => 'Bez e c’halloc’h non pas kargañ ar scriptoù-mañ evit sklerijenniñ pajennoù foran. 
Neuze, forzh penaos vefe renket ar forom, pe kreionoù ha pluginoù, benveg Quill ebet ne vo war al lec’hienn foran en un doare emgefreek.',

	// I
	'info_barre_outils_public' => 'Barennoù benveg foran',
	'info_porte_plume_titre' => 'Ardremm ar barennoù benveg',

	// L
	'label_barre_outils_public_non' => 'Arabat kargañ skriptoù ar barennoù benveg e-barzh al lec’hienn foran.',
	'label_barre_outils_public_oui' => 'Kargañ skriptoù ar barennoù benveg e-barzh al lec’hienn foran.',

	// V
	'voir' => 'Gwelet en araok'
);
